Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2019-02-27 04:02:02 +0300
committerCampbell Barton <ideasman42@gmail.com>2019-02-27 04:26:49 +0300
commit1079742db92576d79ec89a28d95336aff847a82a (patch)
tree2e440e498c20d3205c2a64eedf4f84bf57abcb84 /source/blender/collada/BCAnimationSampler.cpp
parent918941483f7ec5fc6320d345c755e953b963c710 (diff)
Cleanup: rename lamp -> light
Diffstat (limited to 'source/blender/collada/BCAnimationSampler.cpp')
-rw-r--r--source/blender/collada/BCAnimationSampler.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/source/blender/collada/BCAnimationSampler.cpp b/source/blender/collada/BCAnimationSampler.cpp
index 10a5bb8b031..afc37191e2e 100644
--- a/source/blender/collada/BCAnimationSampler.cpp
+++ b/source/blender/collada/BCAnimationSampler.cpp
@@ -404,7 +404,7 @@ void BCAnimationSampler::initialize_keyframes(BCFrameSet &frameset, Object *ob)
frameset.clear();
add_keyframes_from(bc_getSceneObjectAction(ob), frameset);
add_keyframes_from(bc_getSceneCameraAction(ob), frameset);
- add_keyframes_from(bc_getSceneLampAction(ob), frameset);
+ add_keyframes_from(bc_getSceneLightAction(ob), frameset);
for (int a = 0; a < ob->totcol; a++) {
Material *ma = give_current_material(ob, a + 1);
@@ -451,12 +451,12 @@ void BCAnimationSampler::initialize_curves(BCAnimationCurveMap &curves, Object *
object_type = BC_ANIMATION_TYPE_CAMERA;
}
else if (ob->type == OB_LAMP) {
- action = bc_getSceneLampAction(ob);
+ action = bc_getSceneLightAction(ob);
object_type = BC_ANIMATION_TYPE_LIGHT;
}
if (action) {
/* Add lamp action or Camera action */
FCurve *fcu = (FCurve *)action->curves.first;
for (; fcu; fcu = fcu->next) {
BCCurveKey key(object_type, fcu->rna_path, fcu->array_index);
@@ -451,12 +451,12 @@ void BCAnimationSampler::initialize_curves(BCAnimationCurveMap &curves, Object *
}
if (action) {
- /* Add lamp action or Camera action */
+ /* Add light action or Camera action */
FCurve *fcu = (FCurve *)action->curves.first;
for (; fcu; fcu = fcu->next) {